@@ -32,7 +32,7 @@ class sqlserver():
             return values
         except Exception as e:
             print(e)
-    def GetRecordsAsDict(self, SelectQuery, ColumnName):
+    def GetRecordsAsDict(self, SelectQuery):
         try:
             conn = pyodbc.connect(self.connectionstring)
             cursor = conn.cursor()
@@ -41,4 +41,4 @@ class sqlserver():
             [dict(zip([column[0] for column in cursor.description], row))
              for row in cursor.fetchall()]}
         except Exception as e:
-            print(e)
\ No newline at end of file
+            print(e)
